@@ -1,7 +1,7 @@
 #' Fit 'Stan' models to nucleotide recoding RNA-seq data analysis
 #'
 #' \code{TL_stan} is an internal function to analyze nucleotide recoding RNA-seq data with a fully
-#' Bayesian hierarchical model implemented in the PPL Stan. \code{TL_stan} estimates
+#' Bayesian hierarchical model implemented in the PPL `Stan`. \code{TL_stan} estimates
 #' kinetic parameters and differences in kinetic parameters between experimental
 #' conditions. When assessing differences, a single reference sample is compared to
 #' each collection of experimental samples provided.
@@ -13,7 +13,7 @@
 #' with rate parameter adjusted by the empirical U-content of each feature analyzed. Features
 #' represent whatever the user defined them to be when constructing the bakR data object.
 #' Typical feature categories are genes, exons, etc. Hierarchical modeling is used to pool data
-#' across replicates, across features, and across replicates. More specifically, replicate data for the
+#' across replicates and across features. More specifically, replicate data for the
 #' same feature are partially pooled to estimate feature-specific mean fraction news and uncertainties.
 #' Feature means are partially pooled to estimate dataset-wide mean fraction news and standard deviations.
 #' The replicate variability for each feature is also partially pooled to determine a condition-wide
@@ -27,12 +27,12 @@
 #' inherits the hierarchical modeling structure of the complete analysis, but reduces computational
 #' burden by foregoing per-replicate-and-feature fraction new estimation and uncertainty quantification. Instead,
 #' the hybrid analysis takes as data fraction new estimates and approximate uncertainties from \code{fast_analysis}.
-#' Runtimes of the hybrid analysis are thus often an order or magnitude or more shorter than with the complete analysis, but
+#' Runtimes of the hybrid analysis are thus often an order of magnitude shorter than with the complete analysis, but
 #' loses some accuracy by relying on point estimates and uncertainty quantification that is only valid in the
 #' limit of large dataset sizes (where the dataset size for the per-replicate-and-feature fraction new estimate is the raw number
 #' of sequencing reads mapping to the feature in that replicate).
 #'
-#' Users also have the option to save or discard the 'Stan' fit object. Fit objects can be exceedingly large (> 10 GB) for most
+#' Users also have the option to save or discard the `Stan` fit object. Fit objects can be exceedingly large (> 10 GB) for most
 #' nucleotide recoding RNA-seq datasets. Therefore, if you don't want to store such a large object, a summary object will be saved instead,
 #' which greatly reduces the size of the output (~ 10-50 MB) while still retaining much of the important information. In addition,
 #' the output of \code{TL_stan} provides the estimates and uncertainties for key parameters (L2FC(kdeg), kdeg, and fraction new)
@@ -59,7 +59,7 @@
 #' with around 20 million raw (unmapped) reads per sample requires over 100 GB of RAM. With a single chain, this burden drops to
 #' around 20 GB. Due to memory demands and time constraints (runtimes for the MCMC implementation border will likely be around 1-2 days)
 #' means that these models should usually be run in a specialized High Performance Computing (HPC) system.
-#' @param ... Arguments passed to `rstan::sampling` (e.g. iter, warmup, etc.).
+#' @param ... Arguments passed to \code{rstan::sampling} (e.g. iter, warmup, etc.).
 #' @return A list of objects:
 #' \itemize{
 #'  \item Effects_df; dataframe with estimates of the effect size (change in logit(fn)) comparing each experimental condition to the
@@ -83,6 +83,8 @@
 #'   \item Exp_ID; Numerical ID for experimental condition
 #'   \item kdeg; Degradation rate constant posterior mean
 #'   \item kdeg_sd; Degradation rate constant posterior standard deviation
+#'   \item log_kdeg; Log of degradation rate constant posterior mean (as of version 1.0.0)
+#'   \item log_kdeg_sd; Log of degradation rate constant posterior standard deviation (as of version 1.0.0)
 #'   \item XF; Original feature name
 #'  }
 #'  \item Fn_Estimates; dataframe with estimates of the logit(fraction new) for each feature in each replicate.
@@ -164,17 +166,17 @@ TL_stan <- function(data_list, Hybrid_Fit = FALSE, keep_fit = FALSE, NSS = FALSE
   # relationship between fraction new and degradation rate constan
   if(Hybrid_Fit){ # Run Hybrid implementation
     if(NSS){
-      fit <- rstan::sampling(stanmodels$Hybrid_NSS2, data = data_list, chains = chains, ...)
+      fit <- rstan::sampling(stanmodels$Hybrid_NSS, data = data_list, chains = chains, ...)
 
     }else{
-      fit <- rstan::sampling(stanmodels$Hybrid2, data = data_list, chains = chains, ...)
+      fit <- rstan::sampling(stanmodels$Hybrid, data = data_list, chains = chains, ...)
 
     }
   }else{ # Run MCMC implementation
     if(NSS){
-      fit <- rstan::sampling(stanmodels$MCMC_NSS2, data = data_list, chains = chains, ...)
+      fit <- rstan::sampling(stanmodels$MCMC_NSS, data = data_list, chains = chains, ...)
     }else{
-      fit <- rstan::sampling(stanmodels$MCMC, data = data_list, chains = chains, ...)
+      fit <- rstan::sampling(stanmodels$MCMC2, data = data_list, chains = chains, ...)
 
     }
 
@@ -199,7 +201,15 @@ TL_stan <- function(data_list, Hybrid_Fit = FALSE, keep_fit = FALSE, NSS = FALSE
   MT_summary <- MT_summary[, c("50%","mean", "sd")]
 
   MT_summary <- as.data.frame(MT_summary)
+  
+  # Extract log(kdeg) estimates
+  lkd_summary <- rstan::summary(fit, pars = "log_kd", probs = c(0.5))$summary
+  
+  lkd_summary <- lkd_summary[, c("50%","mean", "sd")]
+  
+  lkd_summary <- as.data.frame(lkd_summary)
 
+  # Number of non-reference experimental conditions
   nconds <- data_list$nMT - 1
 
 
@@ -237,15 +247,18 @@ TL_stan <- function(data_list, Hybrid_Fit = FALSE, keep_fit = FALSE, NSS = FALSE
   Exp_ID_kd <- rep(seq(from=1, to=(nconds+1)), times=ngs)
   kdeg <- MT_summary$mean # kdeg vector
   kdeg_sd <- MT_summary$sd # kdeg sd vector
+  log_kdeg <- lkd_summary$mean # log(kdeg) vector
+  log_kdeg_sd <- lkd_summary$sd # log(kdeg) sd vector
 
   rm(MT_summary)
+  rm(lkd_summary)
 
   Effects_df <- data.frame(F_ID, Exp_ID, L2FC_kdeg, L2FC_kdeg_sd, L2FC_kdeg, L2FC_kdeg_sd)
-  Kdeg_df <- data.frame(F_ID_kd, Exp_ID_kd, kdeg, kdeg_sd)
+  Kdeg_df <- data.frame(F_ID_kd, Exp_ID_kd, kdeg, kdeg_sd, log_kdeg, log_kdeg_sd)
   Fn_df <- data.frame(F_ID_fn, Exp_ID_fn, R_ID_fn, logit_fn, fn_se)
 
   colnames(Effects_df) <- c("Feature_ID", "Exp_ID", "L2FC_kdeg", "L2FC_kd_sd", "effect", "se")
-  colnames(Kdeg_df) <- c("Feature_ID", "Exp_ID", "kdeg", "kdeg_sd")
+  colnames(Kdeg_df) <- c("Feature_ID", "Exp_ID", "kdeg", "kdeg_sd", "log_kdeg", "log_kdeg_sd")
   colnames(Fn_df) <- c("Feature_ID", "Exp_ID", "Replicate", "logit_fn", "logit_fn_se")
 
   Fn_df <- merge(Fn_df, data_list$sample_lookup, by.x = c("Exp_ID", "Replicate"), by.y = c("mut", "reps"))
